@@ -84,7 +84,8 @@ class Lotus:
     def check_modify(self, symbol, sl):
         res = self.order.modifiy_stop(symbol, sl)
         if type(res) is str:
-            print('Modify order Error {}:'.format(symbol), res, flush=True)
+            if 'noValChanged' not in res:
+                print('Modify order Error {}:'.format(symbol), res, flush=True)
         else:
             print('Modifying order in {} to new stoploss: {}'.format(
                 symbol, sl), flush=True)
@@ -97,7 +98,7 @@ class Lotus:
             time.sleep(3)
         elif self.order.props[symbol]['open']:
             print("Close old order {} first, because of new signal".format(symbol))
-            self.order.close(symbol, self.client.open_contracts(symbol))  # cancel old order first
+            self.order.close(symbol, -self.client.open_contracts(symbol))  # cancel old order first
             time.sleep(3)
 
     def process_signals(self, ns, start=False):
@@ -184,7 +185,7 @@ class Lotus:
                     else:
                         if self.order.props[symbol]['open']:
                             self.order.close(symbol)
-            else:
+            elif signal != 0:
                 self.manage_open_stop_orders(symbol)
                 print("This position update in {} is only for premium members. Next update: {}".format(symbol,
                                                                                                        self.ceil_dt(datetime.datetime.now(), datetime.timedelta(minutes=30))), flush=True)
